# frozen_string_literal: true

module Gitlab
  module GitalyClient
    class MercurialRepositoryService
      include Gitlab::EncodingHelper

      # 'repository' is a Mercurial subclass of Gitlab::Git::Repository
      def initialize(repository)
        @repository = repository
        @gitaly_repo = repository.gitaly_repository
        @storage = Gitlab::GitalyClient.vcs_qualified_storage(
          repository.storage, 'hg')
      end

      def config_item_bool(section, item)
        request = Hgitaly::GetConfigItemRequest.new(
          repository: @gitaly_repo,
          section: section,
          name: item,
          as_type: Hgitaly::ConfigItemType::BOOL
        )
        response = GitalyClient.call(
          @storage, :mercurial_repository_service, :get_config_item, request,
          timeout: GitalyClient.fast_timeout
        )
        response.as_bool
      end

      def push(remote_url, only_branches_matching: [], ssh_key: nil, known_hosts: nil, include_drafts: false)
        remote_peer = Hgitaly::MercurialPeer.new(
          url: remote_url,
          ssh_key: ssh_key,
          ssh_known_hosts: known_hosts
        )
        request = Hgitaly::PushRequest.new(
          repository: @gitaly_repo,
          remote_peer: remote_peer,
          only_gitlab_branches_matching: only_branches_matching,
          include_drafts: include_drafts
        )
        response = GitalyClient.call(
          @storage, :mercurial_repository_service, :push, request,
          timeout: GitalyClient.long_timeout
        )
        response.new_changesets
      end
    end
  end
end
